import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import ExclamationCircle from './ExclamationCircle'
import theme from './theme'
import splitProps from '../utils/splitProps'

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary[0]}`
  }
})

const Input = ({ warning, className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display/g)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      {warning ? <ExclamationCircle position='absolute' top='50%' marginLeft='-5px' marginTop='-6px' /> : null}
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

Input.propTypes = {
  ...Box.propTypes,
  warning: PropTypes.bool
}

Input.defaultProps = {
  theme,
  rounded: true,
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Input.displayName = 'Input'

export default Input
