import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'
import splitProps from '../utils/splitProps'

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary[0]}`
  }
})

const SearchInput = ({ className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display/g)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      <SearchIcon size='small' position='absolute' top='50%' marginLeft={3} marginTop='-8px' />
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

SearchInput.propTypes = {
  ...Box.propTypes
}

SearchInput.defaultProps = {
  theme,
  circle: true,
  paddingX: 4,
  paddingLeft: 7,
  paddingY: 2,
  textStyle: 'body1'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput
